@@ -110,7 +110,7 @@
 #' visited. In that way, deterministic relation between columns will always be
 #' synchronized.
 #'
-#' #'A new argument \code{ls.meth} can be parsed to the lower level
+#' A new argument \code{ls.meth} can be parsed to the lower level
 #' \code{.norm.draw} to specify the method for generating the least squares
 #' estimates and any subsequently derived estimates. Argument \code{ls.meth}
 #' takes one of three inputs: \code{"qr"} for QR-decomposition, \code{"svd"} for
@@ -203,6 +203,18 @@
 #' The \code{formulas} argument is an alternative to the
 #' \code{predictorMatrix} argument that allows for more flexibility in
 #' specifying imputation models, e.g., for specifying interaction terms.
+#' @param calltype A character vector of \code{length(block)} elements
+#' that indicates how the imputation model is specified. Entries can
+#' one of two values: \code{"pred"} or \code{"formula"}. If
+#' \code{calltype = "pred"}, the predictors of the imputation
+#' model for the block are specified by the corresponding row of the
+#' \code{predictorMatrix}. If  \code{calltype = "formula"} the
+#' imputation model is specified by relevant entry in
+#' \code{formulas}. The default depends on the presence of the
+#' \code{formulas} argument. If \code{formulas} is present, then
+#' \code{mice()} sets
+#' \code{calltype = "formula"} for any block
+#' for which a formula is specified. Otherwise, \code{calltype = "pred"}.
 #' @param blots A named \code{list} of \code{alist}'s that can be used
 #' to pass down arguments to lower level imputation function. The entries
 #' of element \code{blots[[blockname]]} are passed down to the function
@@ -251,7 +263,7 @@
 #' \doi{10.18637/jss.v045.i03}
 #'
 #' Van Buuren, S. (2018).
-#' \href{https://stefvanbuuren.name/fimd/sec-FCS.html#sec:MICE}{\emph{Flexible Imputation of Missing Data. Second Edition.}}
+#' \emph{Flexible Imputation of Missing Data. Second Edition.}
 #' Chapman & Hall/CRC. Boca Raton, FL.
 #'
 #' Van Buuren, S., Brand, J.P.L., Groothuis-Oudshoorn C.G.M., Rubin, D.B. (2006)
@@ -263,8 +275,8 @@
 #' Research}, \bold{16}, 3, 219--242.
 #'
 #' Van Buuren, S., Boshuizen, H.C., Knook, D.L. (1999) Multiple imputation of
-#' missing blood pressure covariates in survival analysis.  \emph{Statistics in
-#' Medicine}, \bold{18}, 681--694.
+#' missing blood pressure covariates in survival analysis.
+#' \emph{Statistics in Medicine}, \bold{18}, 681--694.
 #'
 #' Brand, J.P.L. (1999) \emph{Development, implementation and evaluation of
 #' multiple imputation strategies for the statistical analysis of incomplete
@@ -315,6 +327,7 @@ mice <- function(data,
                  blocks,
                  visitSequence = NULL,
                  formulas,
+                 calltype = NULL,
                  blots = NULL,
                  post = NULL,
                  defaultMethod = c("pmm", "logreg", "polyreg", "polr"),
@@ -343,6 +356,7 @@ mice <- function(data,
     blocks <- make.blocks(colnames(data))
     predictorMatrix <- make.predictorMatrix(data, blocks)
     formulas <- make.formulas(data, blocks)
+    calltype <- make.calltype(calltype, predictorMatrix, formulas, "pred")
   }
   # case B
   if (!mp & mb & mf) {
@@ -350,6 +364,7 @@ mice <- function(data,
     predictorMatrix <- check.predictorMatrix(predictorMatrix, data)
     blocks <- make.blocks(colnames(predictorMatrix), partition = "scatter")
     formulas <- make.formulas(data, blocks, predictorMatrix = predictorMatrix)
+    calltype <- make.calltype(calltype, predictorMatrix, formulas, "pred")
   }
 
   # case C
@@ -358,6 +373,7 @@ mice <- function(data,
     blocks <- check.blocks(blocks, data)
     predictorMatrix <- make.predictorMatrix(data, blocks)
     formulas <- make.formulas(data, blocks)
+    calltype <- make.calltype(calltype, predictorMatrix, formulas, "pred")
   }
 
   # case D
@@ -366,6 +382,7 @@ mice <- function(data,
     formulas <- check.formulas(formulas, data)
     blocks <- construct.blocks(formulas)
     predictorMatrix <- make.predictorMatrix(data, blocks)
+    calltype <- make.calltype(calltype, predictorMatrix, formulas, "formula")
   }
 
   # case E
@@ -376,6 +393,7 @@ mice <- function(data,
     predictorMatrix <- z$predictorMatrix
     blocks <- z$blocks
     formulas <- make.formulas(data, blocks, predictorMatrix = predictorMatrix)
+    calltype <- make.calltype(calltype, predictorMatrix, formulas, "pred")
   }
 
   # case F
@@ -385,14 +403,16 @@ mice <- function(data,
     predictorMatrix <- check.predictorMatrix(predictorMatrix, data)
     blocks <- construct.blocks(formulas, predictorMatrix)
     predictorMatrix <- make.predictorMatrix(data, blocks, predictorMatrix)
+    calltype <- make.calltype(calltype, predictorMatrix, formulas, "formula")
   }
 
   # case G
   if (mp & !mb & !mf) {
     # blocks lead
-    blocks <- check.blocks(blocks, data, calltype = "formula")
+    blocks <- check.blocks(blocks, data)
     formulas <- check.formulas(formulas, blocks)
     predictorMatrix <- make.predictorMatrix(data, blocks)
+    calltype <- make.calltype(calltype, predictorMatrix, formulas, "formula")
   }
 
   # case H
@@ -401,6 +421,7 @@ mice <- function(data,
     blocks <- check.blocks(blocks, data)
     formulas <- check.formulas(formulas, data)
     predictorMatrix <- check.predictorMatrix(predictorMatrix, data, blocks)
+    calltype <- make.calltype(calltype, predictorMatrix, formulas, "formula")
   }
 
   chk <- check.cluster(data, predictorMatrix)
@@ -411,7 +432,7 @@ mice <- function(data,
   visitSequence <- check.visitSequence(visitSequence,
     data = data, where = where, blocks = blocks
   )
-  predictorMatrix <- edit.predictorMatrix(
+  predictorMatrix <- mice.edit.predictorMatrix(
     predictorMatrix = predictorMatrix,
     visitSequence = visitSequence,
     user.visitSequence = user.visitSequence,
@@ -436,7 +457,7 @@ mice <- function(data,
     visitSequence = visitSequence,
     post = post
   )
-  setup <- edit.setup(data, setup, ...)
+  setup <- mice.edit.setup(data, setup, user.visitSequence, ...)
   method <- setup$method
   predictorMatrix <- setup$predictorMatrix
   visitSequence <- setup$visitSequence
@@ -454,7 +475,8 @@ mice <- function(data,
   to <- from + maxit - 1
   q <- sampler(
     data, m, ignore, where, imp, blocks, method,
-    visitSequence, predictorMatrix, formulas, blots,
+    visitSequence, predictorMatrix, formulas,
+    calltype, blots,
     post, c(from, to), printFlag, ...
   )
 
@@ -462,7 +484,7 @@ mice <- function(data,
   if (state$log) row.names(loggedEvents) <- seq_len(nrow(loggedEvents))
 
   ## save, and return
-  midsobj <- list(
+  midsobj <- mids(
     data = data,
     imp = q$imp,
     m = m,
@@ -474,6 +496,7 @@ mice <- function(data,
     predictorMatrix = predictorMatrix,
     visitSequence = visitSequence,
     formulas = formulas,
+    calltype = calltype,
     post = post,
     blots = blots,
     ignore = ignore,
@@ -481,20 +504,15 @@ mice <- function(data,
     iteration = q$iteration,
     lastSeedValue = get(".Random.seed",
       envir = globalenv(), mode = "integer",
-      inherits = FALSE
-    ),
+      inherits = FALSE),
     chainMean = q$chainMean,
     chainVar = q$chainVar,
-    loggedEvents = loggedEvents,
-    version = packageVersion("mice"),
-    date = Sys.Date()
-  )
-  oldClass(midsobj) <- "mids"
+    loggedEvents = loggedEvents)
 
   if (!is.null(midsobj$loggedEvents)) {
     warning("Number of logged events: ", nrow(midsobj$loggedEvents),
       call. = FALSE
     )
   }
-  midsobj
+  return(midsobj)
 }
