@@ -23,7 +23,7 @@
 #'
 #' van Buuren S and Groothuis-Oudshoorn K (2011). \code{mice}: Multivariate
 #' Imputation by Chained Equations in \code{R}. \emph{Journal of Statistical
-#' Software}, \bold{45}(3), 1-67. \url{https://www.jstatsoft.org/v45/i03/}
+#' Software}, \bold{45}(3), 1-67. \doi{10.18637/jss.v045.i03}
 #'
 
 #' @keywords htest
@@ -72,7 +72,8 @@ pool.r.squared <- function(object, adjusted = FALSE) {
 
   # Fill arrays
   for (i in seq_len(m)) {
-    r2[i, 1] <- if (!adjusted) sqrt(glanced$r.squared[i]) else sqrt(glanced$adj.r.squared[i])
+    r2[i, 1] <- if (!adjusted) sqrt(glanced$r.squared[i]) else
+      sign(glanced$adj.r.squared[i]) * sqrt(abs(glanced$adj.r.squared[i]))
     r2[i, 2] <- 0.5 * log((r2[i, 1] + 1) / (1 - r2[i, 1]))
     r2[i, 3] <- 1 / (glanced$nobs[i] - 3)
   }
